/************************************************************************
* wgserial Javascript Module
* Copyright (C) 2016  Klaus Weichinger snaky.1@gmx.at
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*************************************************************************/

var SerialPort = require('serialport').SerialPort;

var wgserial = function(options)
{
  var serial;
  var myobject={
    write: function(s) {
      if (serial.isOpen()) serial.write(s);
    },

    serial: serial
  };

  function reconnect()
  {
    serial=new SerialPort(options.comport, {
      baudRate: options.baudrate,
      dataBits: 8,
      parity: 'none',
      stopBits: 1
    },false);

    serial.on('open',function(){
      console.log("Serial port '"+options.comport+"' opened!");
    });

    serial.on('error',function(err) {
      console.log("Serial port try reconnecting '"+options.comport+"' ...");
      if (serial.isOpen()) serial.close();
      setTimeout(function() { reconnect(); }, options.reconnectperiode || 1000);
    });

    serial.on('data',function(data) {
      var s=data.toString();
      if (options.ondata) options.ondata(s);
    });

    serial.on('error', function(error) {
    });

    serial.on('disconnect', function(object) {
      console.log("Serial port '"+options.comport+"' disconnected!");
      reconnect();
    });

    serial.open();
  }

  reconnect();
  return myobject;
};

module.exports = wgserial;
